# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/environments/environment_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.v0.environments import environment_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_environment__pb2
from _qwak_proto.qwak.administration.v0.environments import configuration_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_configuration__pb2
from _qwak_proto.qwak.administration.v0.environments import personalization_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_personalization__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=qwak/administration/v0/environments/environment_service.proto\x12\x1fqwak.administration.environment\x1a\x35qwak/administration/v0/environments/environment.proto\x1a\x37qwak/administration/v0/environments/configuration.proto\x1a\x39qwak/administration/v0/environments/personalization.proto\"\x9f\x02\n\x18\x43reateEnvironmentRequest\x12\x18\n\x10\x65nvironment_name\x18\x01 \x01(\t\x12\x15\n\ttenant_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x12\n\naccount_id\x18\x04 \x01(\t\x12\x12\n\ncluster_id\x18\x06 \x01(\t\x12T\n\rconfiguration\x18\x03 \x01(\x0b\x32=.qwak.administration.environment.QwakEnvironmentConfiguration\x12T\n\x0fpersonalization\x18\x05 \x01(\x0b\x32;.qwak.administration.environment.EnvironmentPersonalization\"b\n\x19\x43reateEnvironmentResponse\x12\x45\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x30.qwak.administration.environment.QwakEnvironment\"\x95\x01\n%UpdateEnvironmentConfigurationRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12T\n\rconfiguration\x18\x02 \x01(\x0b\x32=.qwak.administration.environment.QwakEnvironmentConfiguration\"(\n&UpdateEnvironmentConfigurationResponse\"\x97\x01\n\'UpdateEnvironmentPersonalizationRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12T\n\x0fpersonalization\x18\x02 \x01(\x0b\x32;.qwak.administration.environment.EnvironmentPersonalization\"*\n(UpdateEnvironmentPersonalizationResponse\"/\n\x15GetEnvironmentRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"_\n\x16GetEnvironmentResponse\x12\x45\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x30.qwak.administration.environment.QwakEnvironment\"I\n/GetEnvironmentApplicationUserCredentialsRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"\x8f\x01\n0GetEnvironmentApplicationUserCredentialsResponse\x12[\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32\x46.qwak.administration.environment.EnvironmentApplicationUserCredentials\"\xa6\x01\n/SetEnvironmentApplicationUserCredentialsRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12[\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x46.qwak.administration.environment.EnvironmentApplicationUserCredentials\"2\n0SetEnvironmentApplicationUserCredentialsResponse\"\xc8\x01\n\x17ListEnvironmentsRequest\x12O\n\x06\x66ilter\x18\x01 \x01(\x0b\x32?.qwak.administration.environment.ListEnvironmentsRequest.Filter\x1a\\\n\x06\x46ilter\x12R\n\x12\x65nvironment_status\x18\x01 \x01(\x0e\x32\x36.qwak.administration.environment.QwakEnvironmentStatus\"b\n\x18ListEnvironmentsResponse\x12\x46\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32\x30.qwak.administration.environment.QwakEnvironment2\xc1\t\n\x12\x45nvironmentService\x12\x8a\x01\n\x11\x43reateEnvironment\x12\x39.qwak.administration.environment.CreateEnvironmentRequest\x1a:.qwak.administration.environment.CreateEnvironmentResponse\x12\x81\x01\n\x0eGetEnvironment\x12\x36.qwak.administration.environment.GetEnvironmentRequest\x1a\x37.qwak.administration.environment.GetEnvironmentResponse\x12\xb1\x01\n\x1eUpdateEnvironmentConfiguration\x12\x46.qwak.administration.environment.UpdateEnvironmentConfigurationRequest\x1aG.qwak.administration.environment.UpdateEnvironmentConfigurationResponse\x12\xb7\x01\n UpdateEnvironmentPersonalization\x12H.qwak.administration.environment.UpdateEnvironmentPersonalizationRequest\x1aI.qwak.administration.environment.UpdateEnvironmentPersonalizationResponse\x12\x87\x01\n\x10ListEnvironments\x12\x38.qwak.administration.environment.ListEnvironmentsRequest\x1a\x39.qwak.administration.environment.ListEnvironmentsResponse\x12\xcf\x01\n(GetEnvironmentApplicationUserCredentials\x12P.qwak.administration.environment.GetEnvironmentApplicationUserCredentialsRequest\x1aQ.qwak.administration.environment.GetEnvironmentApplicationUserCredentialsResponse\x12\xcf\x01\n(SetEnvironmentApplicationUserCredentials\x12P.qwak.administration.environment.SetEnvironmentApplicationUserCredentialsRequest\x1aQ.qwak.administration.environment.SetEnvironmentApplicationUserCredentialsResponseB\xb2\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0b\x06proto3')



_CREATEENVIRONMENTREQUEST = DESCRIPTOR.message_types_by_name['CreateEnvironmentRequest']
_CREATEENVIRONMENTRESPONSE = DESCRIPTOR.message_types_by_name['CreateEnvironmentResponse']
_UPDATEENVIRONMENTCONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateEnvironmentConfigurationRequest']
_UPDATEENVIRONMENTCONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateEnvironmentConfigurationResponse']
_UPDATEENVIRONMENTPERSONALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateEnvironmentPersonalizationRequest']
_UPDATEENVIRONMENTPERSONALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateEnvironmentPersonalizationResponse']
_GETENVIRONMENTREQUEST = DESCRIPTOR.message_types_by_name['GetEnvironmentRequest']
_GETENVIRONMENTRESPONSE = DESCRIPTOR.message_types_by_name['GetEnvironmentResponse']
_GETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST = DESCRIPTOR.message_types_by_name['GetEnvironmentApplicationUserCredentialsRequest']
_GETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE = DESCRIPTOR.message_types_by_name['GetEnvironmentApplicationUserCredentialsResponse']
_SETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST = DESCRIPTOR.message_types_by_name['SetEnvironmentApplicationUserCredentialsRequest']
_SETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE = DESCRIPTOR.message_types_by_name['SetEnvironmentApplicationUserCredentialsResponse']
_LISTENVIRONMENTSREQUEST = DESCRIPTOR.message_types_by_name['ListEnvironmentsRequest']
_LISTENVIRONMENTSREQUEST_FILTER = _LISTENVIRONMENTSREQUEST.nested_types_by_name['Filter']
_LISTENVIRONMENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListEnvironmentsResponse']
CreateEnvironmentRequest = _reflection.GeneratedProtocolMessageType('CreateEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENVIRONMENTREQUEST,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.CreateEnvironmentRequest)
  })
_sym_db.RegisterMessage(CreateEnvironmentRequest)

CreateEnvironmentResponse = _reflection.GeneratedProtocolMessageType('CreateEnvironmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENVIRONMENTRESPONSE,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.CreateEnvironmentResponse)
  })
_sym_db.RegisterMessage(CreateEnvironmentResponse)

UpdateEnvironmentConfigurationRequest = _reflection.GeneratedProtocolMessageType('UpdateEnvironmentConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENVIRONMENTCONFIGURATIONREQUEST,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.UpdateEnvironmentConfigurationRequest)
  })
_sym_db.RegisterMessage(UpdateEnvironmentConfigurationRequest)

UpdateEnvironmentConfigurationResponse = _reflection.GeneratedProtocolMessageType('UpdateEnvironmentConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENVIRONMENTCONFIGURATIONRESPONSE,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.UpdateEnvironmentConfigurationResponse)
  })
_sym_db.RegisterMessage(UpdateEnvironmentConfigurationResponse)

UpdateEnvironmentPersonalizationRequest = _reflection.GeneratedProtocolMessageType('UpdateEnvironmentPersonalizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENVIRONMENTPERSONALIZATIONREQUEST,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.UpdateEnvironmentPersonalizationRequest)
  })
_sym_db.RegisterMessage(UpdateEnvironmentPersonalizationRequest)

UpdateEnvironmentPersonalizationResponse = _reflection.GeneratedProtocolMessageType('UpdateEnvironmentPersonalizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENVIRONMENTPERSONALIZATIONRESPONSE,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.UpdateEnvironmentPersonalizationResponse)
  })
_sym_db.RegisterMessage(UpdateEnvironmentPersonalizationResponse)

GetEnvironmentRequest = _reflection.GeneratedProtocolMessageType('GetEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTREQUEST,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.GetEnvironmentRequest)
  })
_sym_db.RegisterMessage(GetEnvironmentRequest)

GetEnvironmentResponse = _reflection.GeneratedProtocolMessageType('GetEnvironmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTRESPONSE,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.GetEnvironmentResponse)
  })
_sym_db.RegisterMessage(GetEnvironmentResponse)

GetEnvironmentApplicationUserCredentialsRequest = _reflection.GeneratedProtocolMessageType('GetEnvironmentApplicationUserCredentialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.GetEnvironmentApplicationUserCredentialsRequest)
  })
_sym_db.RegisterMessage(GetEnvironmentApplicationUserCredentialsRequest)

GetEnvironmentApplicationUserCredentialsResponse = _reflection.GeneratedProtocolMessageType('GetEnvironmentApplicationUserCredentialsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.GetEnvironmentApplicationUserCredentialsResponse)
  })
_sym_db.RegisterMessage(GetEnvironmentApplicationUserCredentialsResponse)

SetEnvironmentApplicationUserCredentialsRequest = _reflection.GeneratedProtocolMessageType('SetEnvironmentApplicationUserCredentialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.SetEnvironmentApplicationUserCredentialsRequest)
  })
_sym_db.RegisterMessage(SetEnvironmentApplicationUserCredentialsRequest)

SetEnvironmentApplicationUserCredentialsResponse = _reflection.GeneratedProtocolMessageType('SetEnvironmentApplicationUserCredentialsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.SetEnvironmentApplicationUserCredentialsResponse)
  })
_sym_db.RegisterMessage(SetEnvironmentApplicationUserCredentialsResponse)

ListEnvironmentsRequest = _reflection.GeneratedProtocolMessageType('ListEnvironmentsRequest', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTENVIRONMENTSREQUEST_FILTER,
    '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
    # @@protoc_insertion_point(class_scope:qwak.administration.environment.ListEnvironmentsRequest.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTENVIRONMENTSREQUEST,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.ListEnvironmentsRequest)
  })
_sym_db.RegisterMessage(ListEnvironmentsRequest)
_sym_db.RegisterMessage(ListEnvironmentsRequest.Filter)

ListEnvironmentsResponse = _reflection.GeneratedProtocolMessageType('ListEnvironmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENVIRONMENTSRESPONSE,
  '__module__' : 'qwak.administration.v0.environments.environment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.ListEnvironmentsResponse)
  })
_sym_db.RegisterMessage(ListEnvironmentsResponse)

_ENVIRONMENTSERVICE = DESCRIPTOR.services_by_name['EnvironmentService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0'
  _CREATEENVIRONMENTREQUEST.fields_by_name['tenant_id']._options = None
  _CREATEENVIRONMENTREQUEST.fields_by_name['tenant_id']._serialized_options = b'\030\001'
  _CREATEENVIRONMENTREQUEST._serialized_start=270
  _CREATEENVIRONMENTREQUEST._serialized_end=557
  _CREATEENVIRONMENTRESPONSE._serialized_start=559
  _CREATEENVIRONMENTRESPONSE._serialized_end=657
  _UPDATEENVIRONMENTCONFIGURATIONREQUEST._serialized_start=660
  _UPDATEENVIRONMENTCONFIGURATIONREQUEST._serialized_end=809
  _UPDATEENVIRONMENTCONFIGURATIONRESPONSE._serialized_start=811
  _UPDATEENVIRONMENTCONFIGURATIONRESPONSE._serialized_end=851
  _UPDATEENVIRONMENTPERSONALIZATIONREQUEST._serialized_start=854
  _UPDATEENVIRONMENTPERSONALIZATIONREQUEST._serialized_end=1005
  _UPDATEENVIRONMENTPERSONALIZATIONRESPONSE._serialized_start=1007
  _UPDATEENVIRONMENTPERSONALIZATIONRESPONSE._serialized_end=1049
  _GETENVIRONMENTREQUEST._serialized_start=1051
  _GETENVIRONMENTREQUEST._serialized_end=1098
  _GETENVIRONMENTRESPONSE._serialized_start=1100
  _GETENVIRONMENTRESPONSE._serialized_end=1195
  _GETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST._serialized_start=1197
  _GETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST._serialized_end=1270
  _GETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE._serialized_start=1273
  _GETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE._serialized_end=1416
  _SETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST._serialized_start=1419
  _SETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST._serialized_end=1585
  _SETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE._serialized_start=1587
  _SETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE._serialized_end=1637
  _LISTENVIRONMENTSREQUEST._serialized_start=1640
  _LISTENVIRONMENTSREQUEST._serialized_end=1840
  _LISTENVIRONMENTSREQUEST_FILTER._serialized_start=1748
  _LISTENVIRONMENTSREQUEST_FILTER._serialized_end=1840
  _LISTENVIRONMENTSRESPONSE._serialized_start=1842
  _LISTENVIRONMENTSRESPONSE._serialized_end=1940
  _ENVIRONMENTSERVICE._serialized_start=1943
  _ENVIRONMENTSERVICE._serialized_end=3160
# @@protoc_insertion_point(module_scope)



from abc import abstractmethod, ABC
from typing import Optional

from qwak.inner.build_logic.interface.build_logger_interface import BuildLogger
from qwak.inner.build_logic.interface.build_phase import BuildPhase
from qwak.inner.build_logic.phases.phases_pipeline import PhasesPipeline


class PhaseRunHandler(ABC):
    current_phase: PhasesPipeline
    build_logger: Optional[BuildLogger]

    @abstractmethod
    def handle_phase_in_progress(self, build_phase: BuildPhase):
        pass

    @abstractmethod
    def handle_phase_finished_successfully(
        self, build_phase: BuildPhase, duration_in_seconds: int
    ):
        pass

    @abstractmethod
    def handle_contact_support_error(
        self,
        build_id: str,
        build_phase: BuildPhase,
        ex: BaseException,
        duration_in_seconds: int,
    ):
        pass

    @abstractmethod
    def handle_remote_build_error(
        self,
        build_id: str,
        build_phase: BuildPhase,
        ex: BaseException,
        duration_in_seconds: int,
    ):
        pass

    @abstractmethod
    def handle_keyboard_interrupt(
        self, build_id: str, build_phase: BuildPhase, duration_in_seconds: int
    ):
        pass

    @abstractmethod
    def handle_pipeline_exception(
        self,
        build_id: str,
        build_phase: BuildPhase,
        ex: BaseException,
        duration_in_seconds: int,
    ):
        pass

    @abstractmethod
    def handle_pipeline_quiet_exception(
        self,
        build_id: str,
        build_phase: BuildPhase,
        ex: BaseException,
        duration_in_seconds: int,
    ):
        pass

    @abstractmethod
    def handle_current_phase(self, phase: PhasesPipeline):
        pass



import os
from pathlib import Path
from typing import Optional

from qwak.exceptions import QwakException
from qwak.feature_store._common import packaging
from qwak.feature_store._common.source_code_spec import SourceCodeSpec, ZipArtifact


class SourceCodeSpecFactory:
    @staticmethod
    def _upload_source_code_dir(main_entity_path: Path, presign_url: str):
        zip_location: Optional[Path] = None
        try:
            zip_location = packaging.zip_source_code_dir(base_path=main_entity_path)
            with open(zip_location, "rb") as zip_file:
                packaging.put_presigned_url(
                    presign_url=presign_url,
                    content=zip_file.read(),
                    content_type="application/octet-stream",
                )
        except Exception as e:
            raise QwakException("Got an error while trying to upload file.") from e
        finally:
            if zip_location:
                os.remove(zip_location)

    @staticmethod
    def get_zip_source_code_spec(
        main_entity_path: Path, presign_url: str
    ) -> SourceCodeSpec:
        """
        Zips and upload the artifact,
        the main "entity" relative path is set as the main_entity_path
        """
        SourceCodeSpecFactory._upload_source_code_dir(
            main_entity_path=main_entity_path, presign_url=presign_url
        )

        parent_base_path = (
            main_entity_path.parent if main_entity_path.is_file() else main_entity_path
        )

        return SourceCodeSpec(
            artifact=ZipArtifact(
                artifact_path=presign_url,
                main_file=str(
                    Path(parent_base_path.name) / Path(main_entity_path.name)
                ),
            )
        )
